summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--common/ioexpander.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/common/ioexpander.c b/common/ioexpander.c
index 9839671a51..c5c06ee8e1 100644
--- a/common/ioexpander.c
+++ b/common/ioexpander.c
@@ -175,8 +175,8 @@ int ioex_init(int ioex)
int flags = g->flags;
if (g->ioex == ioex && g->mask && !(flags & GPIO_DEFAULT)) {
- /* SysJump should not set the output levels */
- if (system_jumped_to_this_image())
+ /* Late-sysJump should not set the output levels */
+ if (system_jumped_late())
flags &= ~(GPIO_LOW | GPIO_HIGH);
drv->set_flags_by_mask(g->ioex, g->port,